==> mgpcli-0.1.51.tar.gz: workflow/lib/component/debug_module.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';

import '../utils/net_util.dart';
import '../utils/sp_util.dart';

enum DebugBtnType { attach, refresh, reload }

class DebugModule extends StatefulWidget {
  final String workspaceDirectory;

  DebugModule(this.workspaceDirectory);

  @override
  DebugModuleState createState() {
    return DebugModuleState(workspaceDirectory);
  }
}

class DebugModuleState extends State<DebugModule> {
  bool attachValid = true;
  String workspaceDirectoryText;
  String targetFileText;
  String alertText = '';
  final TextEditingController _directoryController = TextEditingController();
  final TextEditingController _targetController = TextEditingController();

  DebugModuleState(this.workspaceDirectoryText) {
    targetFileText =
        workspaceDirectoryText != null && workspaceDirectoryText.length > 0
            ? '$workspaceDirectoryText/lib/main.dart'
            : null;
    _directoryController.text = workspaceDirectoryText;
    _targetController.text = targetFileText;
  }

  @override
  void initState() {
    super.initState();
    if (targetFileText == null) {
       fetchDirectoryCache();
    }
  }

  void fetchDirectoryCache() async {
    final targetPathCache = await SpUtil.getString(tPathSpKey);
    final entrancePathCache = await SpUtil.getString(ePathSpKey);
    targetFileText = entrancePathCache;
    _directoryController.text = targetPathCache;
    _targetController.text = targetFileText;
    setState(() {

    });
  }

  Widget debugHeader() {
    const defaultColor = Color(0xFFEEEEEE);
    return Container(
      height: 60,
      color: Colors.black45,
      padding: EdgeInsets.symmetric(horizontal: 20),
      child: Row(
        children: <Widget>[
          Icon(
            Icons.adb,
            color: defaultColor,
            size: 20,
          ),
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 10),
            child: Text(
              'DEBUG',
              style: TextStyle(color: defaultColor, fontSize: 20),
            ),
          )
        ],
      ),
    );
  }

  Widget debugFooter() {
    const defaultColor = Color(0xFF999999);
    return Container(
        padding: EdgeInsets.fromLTRB(20, 0, 20, 100),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Row(
              children: <Widget>[
                Icon(Icons.info_outline, color: defaultColor, size: 20),
                Padding(
                  padding: EdgeInsets.symmetric(horizontal: 10),
                  child: Text(
                    '使用说明：',
                    style: TextStyle(color: defaultColor, fontSize: 20),
                  ),
                ),
              ],
            ),
            Container(
              height: 10,
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: instructionWidgetList(),
            )
          ],
        ));
  }

  List<Widget> instructionWidgetList() {
    const defaultColor = Color(0xFF999999);
    var widgetList = <Widget>[];
    var instructionList = <String>[
      '1. Debug之前请先通过<设备管理>模块选择目标设备；',
      '2. 通过<项目目录>和<入口文件>来设置Dart工程目录及工程入口文件；',
      '3. 如果需要进行断点调试，请使用IDE提供的Flutter Attach及Debug Attach功能；'
    ];
    instructionList.forEach((instructionStr) {
      var widget = Text(
        instructionStr,
        style: TextStyle(color: defaultColor, fontSize: 17),
      );
      widgetList.add(widget);
    });
    return widgetList;
  }

  _btnPress(DebugBtnType btnType) async {
    switch (btnType) {
      case DebugBtnType.attach:
        _requestAttach();
        break;
      case DebugBtnType.reload:
        _requestReload();
        break;
      case DebugBtnType.refresh:
        _requestRefresh();
        break;
      default:
        break;
    }
  }

  _requestAttach() async {
    var paramMap = <String, String>{};
    paramMap['directory'] = _directoryController.text.trim();
    paramMap['target'] = _targetController.text.trim();
    paramMap['device'] = await SpUtil.getString('current_device');
    if (paramMap['directory'] == null || paramMap['directory'].length == 0) {
      alertText = '请先输入项目目录';
      showAlertDialog();
      return;
    }
    if (paramMap['target'] == null || paramMap['target'].length == 0) {
      alertText = '请先输入入口文件';
      showAlertDialog();
      return;
    }
    if (paramMap['device'] == null) {
      alertText = '请先选择需要连接设备';
      showAlertDialog();
      return;
    }
    showLoadingDialog();
    SpUtil.setString(tPathSpKey, paramMap['directory']);
    SpUtil.setString(ePathSpKey, paramMap['target']);
    String dataStr = await NetUtils.get('/api/debug/attach', paramMap);
    hideLoadingDialog();
    Map map = json.decode(dataStr);
    Map dataMap = map['data'];
    alertText = dataMap['message'];
    showAlertDialog();
  }

  _requestRefresh() async {
    String dataStr = await NetUtils.get('/api/debug/refresh',
        <String, String>{'directory': _directoryController.text ?? ''});
    Map map = json.decode(dataStr);
    Map dataMap = map['data'];
    alertText = dataMap['message'];
    showAlertDialog();
  }

  _requestReload() async {
    String dataStr = await NetUtils.get('/api/debug/reload',
        <String, String>{'directory': _directoryController.text ?? ''});
    Map map = json.decode(dataStr);
    Map dataMap = map['data'];
    alertText = dataMap['message'];
    showAlertDialog();
  }

  void showLoadingDialog() {
    showDialog(
      context: context,
      barrierDismissible: false,
      builder: (context) {
        return AlertDialog(
          content: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              LinearProgressIndicator(),
              Padding(
                padding: const EdgeInsets.only(top: 26.0),
                child: Text("正在链接设备，请稍后..."),
              )
            ],
          ),
        );
      },
    );
  }

  void hideLoadingDialog() {
    Navigator.of(context).pop();
  }

  Future<bool> showAlertDialog() {
    return showDialog<bool>(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: Text("提示"),
          content: Text(alertText ?? ''),
          actions: <Widget>[
            FlatButton(
              child: Text("确定"),
              onPressed: () => Navigator.of(context).pop(), // 关闭对话框
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    const btnColor = Color(0xFF444444);
    const btnHoverColor = Color(0xFF666666);
    const btnHighlightColor = Color(0xFF999999);

    return Expanded(
        child: Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        debugHeader(),
        Container(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: TextField(
                controller: _directoryController,
                style: TextStyle(color: Color(0xFF999999)),
                decoration: InputDecoration(
                    prefixIcon: Icon(
                      Icons.folder,
                      color: Color(0xFF999999),
                    ),
                    labelText: '项目目录',
                    labelStyle: TextStyle(color: Color(0xFF999999))),
              ),
            )),
        Container(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: TextField(
                controller: _targetController,
                style: TextStyle(color: Color(0xFF999999)),
                decoration: InputDecoration(
                    prefixIcon: Icon(
                      Icons.assignment_turned_in,
                      color: Color(0xFF999999),
                    ),
                    labelText: '入口文件',
                    labelStyle: TextStyle(color: Color(0xFF999999))),
              ),
            )),
        Container(
          padding: EdgeInsets.only(top: 20),
          alignment: Alignment.center,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Padding(
                  padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                  child: Container(
                    width: 150,
                    child: FlatButton(
                      color: btnColor,
                      highlightColor: btnHighlightColor,
                      colorBrightness: Brightness.dark,
                      splashColor: Colors.grey,
                      hoverColor: btnHoverColor,
                      child: Text("Attach"),
                      onPressed: () {
                        _btnPress(DebugBtnType.attach);
                      },
                    ),
                  )),
              Padding(
                  padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                  child: Container(
                    width: 150,
                    child: FlatButton(
                      padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                      color: btnColor,
                      hoverColor: btnHoverColor,
                      highlightColor: btnHighlightColor,
                      colorBrightness: Brightness.dark,
                      splashColor: Colors.grey,
                      child: Text("Refresh"),
                      onPressed: () {
                        _btnPress(DebugBtnType.refresh);
                      },
                    ),
                  )),
              Padding(
                  padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                  child: Container(
                    width: 150,
                    child: FlatButton(
                      padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                      color: btnColor,
                      hoverColor: btnHoverColor,
                      highlightColor: btnHighlightColor,
                      colorBrightness: Brightness.dark,
                      splashColor: Colors.grey,
                      child: Text("Reload"),
                      onPressed: () {
                        _btnPress(DebugBtnType.reload);
                      },
                    ),
                  )),
            ],
          ),
        ),
        Expanded(
          child: Container(),
        ),
        debugFooter()
      ],
    ));
  }
}

==> mgpcli-0.1.60.tar.gz: workflow/lib/component/debug_module.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:workflow/component/device_manager.dart';

import '../utils/net_util.dart';
import '../utils/sp_util.dart';

enum DebugBtnType { attach, refresh, reload }

class DebugModule extends StatefulWidget {
  final String workspaceDirectory;

  DebugModule(this.workspaceDirectory);

  @override
  DebugModuleState createState() {
    return DebugModuleState(workspaceDirectory);
  }
}

class DebugModuleState extends State<DebugModule> {
  bool attachValid = true;
  String workspaceDirectoryText;
  String targetFileText;
  String alertText = '';
  final TextEditingController _directoryController = TextEditingController();
  final TextEditingController _targetController = TextEditingController();

  DebugModuleState(this.workspaceDirectoryText) {
    targetFileText =
        workspaceDirectoryText != null && workspaceDirectoryText.length > 0
            ? '$workspaceDirectoryText/lib/main.dart'
            : null;
    _directoryController.text = workspaceDirectoryText;
    _targetController.text = targetFileText;
  }

  @override
  void initState() {
    super.initState();
    if (targetFileText == null) {
       fetchDirectoryCache();
    }
  }

  void fetchDirectoryCache() async {
    final targetPathCache = await SpUtil.getString(tPathSpKey);
    final entrancePathCache = await SpUtil.getString(ePathSpKey);
    targetFileText = entrancePathCache;
    _directoryController.text = targetPathCache;
    _targetController.text = targetFileText;
    setState(() {

    });
  }

  Widget debugHeader() {
    const defaultColor = Color(0xFFEEEEEE);
    return Container(
      height: 60,
      color: Colors.black45,
      padding: EdgeInsets.symmetric(horizontal: 20),
      child: Row(
        children: <Widget>[
          Icon(
            Icons.adb,
            color: defaultColor,
            size: 20,
          ),
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 10),
            child: Text(
              'DEBUG',
              style: TextStyle(color: defaultColor, fontSize: 20),
            ),
          )
        ],
      ),
    );
  }

  Widget debugFooter() {
    const defaultColor = Color(0xFF999999);
    return Container(
        padding: EdgeInsets.fromLTRB(20, 0, 20, 100),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Row(
              children: <Widget>[
                Icon(Icons.info_outline, color: defaultColor, size: 20),
                Padding(
                  padding: EdgeInsets.symmetric(horizontal: 10),
                  child: Text(
                    '使用说明：',
                    style: TextStyle(color: defaultColor, fontSize: 20),
                  ),
                ),
              ],
            ),
            Container(
              height: 10,
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: instructionWidgetList(),
            )
          ],
        ));
  }

  List<Widget> instructionWidgetList() {
    const defaultColor = Color(0xFF999999);
    var widgetList = <Widget>[];
    var instructionList = <String>[
      '1. Debug之前请先通过<设备管理>模块选择目标设备；',
      '2. 通过<项目目录>和<入口文件>来设置Dart工程目录及工程入口文件；',
      '3. 如果需要进行断点调试，请使用IDE提供的Flutter Attach及Debug Attach功能；'
    ];
    instructionList.forEach((instructionStr) {
      var widget = Text(
        instructionStr,
        style: TextStyle(color: defaultColor, fontSize: 17),
      );
      widgetList.add(widget);
    });
    return widgetList;
  }

  _btnPress(DebugBtnType btnType) async {
    switch (btnType) {
      case DebugBtnType.attach:
        _requestAttach();
        break;
      case DebugBtnType.reload:
        _requestReload();
        break;
      case DebugBtnType.refresh:
        _requestRefresh();
        break;
      default:
        break;
    }
  }

  _requestAttach() async {
    var paramMap = <String, String>{};
    paramMap['directory'] = _directoryController.text.trim();
    paramMap['target'] = _targetController.text.trim();
    var d = await DeviceManager.currentDevice();
    paramMap['device'] = d.deviceId;
    if (paramMap['directory'] == null || paramMap['directory'].length == 0) {
      alertText = '请先输入项目目录';
      showAlertDialog();
      return;
    }
    if (paramMap['target'] == null || paramMap['target'].length == 0) {
      alertText = '请先输入入口文件';
      showAlertDialog();
      return;
    }
    if (paramMap['device'] == null) {
      alertText = '请先选择需要连接设备';
      showAlertDialog();
      return;
    }
    showLoadingDialog();
    SpUtil.setString(tPathSpKey, paramMap['directory']);
    SpUtil.setString(ePathSpKey, paramMap['target']);
    String dataStr = await NetUtils.get('/api/debug/attach', params: paramMap);
    hideLoadingDialog();
    Map map = json.decode(dataStr);
    Map dataMap = map['data'];
    alertText = dataMap['message'];
    showAlertDialog();
  }

  _requestRefresh() async {
    String dataStr = await NetUtils.get('/api/debug/refresh',
        params: <String, String>{'directory': _directoryController.text ?? ''});
    Map map = json.decode(dataStr);
    Map dataMap = map['data'];
    alertText = dataMap['message'];
    showAlertDialog();
  }

  _requestReload() async {
    String dataStr = await NetUtils.get('/api/debug/reload',
        params: <String, String>{'directory': _directoryController.text ?? ''});
    Map map = json.decode(dataStr);
    Map dataMap = map['data'];
    alertText = dataMap['message'];
    showAlertDialog();
  }

  void showLoadingDialog() {
    showDialog(
      context: context,
      barrierDismissible: false,
      builder: (context) {
        return AlertDialog(
          content: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              LinearProgressIndicator(),
              Padding(
                padding: const EdgeInsets.only(top: 26.0),
                child: Text("正在链接设备，请稍后..."),
              )
            ],
          ),
        );
      },
    );
  }

  void hideLoadingDialog() {
    Navigator.of(context).pop();
  }

  Future<bool> showAlertDialog() {
    return showDialog<bool>(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: Text("提示"),
          content: Text(alertText ?? ''),
          actions: <Widget>[
            FlatButton(
              child: Text("确定"),
              onPressed: () => Navigator.of(context).pop(), // 关闭对话框
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    const btnColor = Color(0xFF444444);
    const btnHoverColor = Color(0xFF666666);
    const btnHighlightColor = Color(0xFF999999);

    return Expanded(
        child: Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        debugHeader(),
        Container(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: TextField(
                controller: _directoryController,
                style: TextStyle(color: Color(0xFF999999)),
                decoration: InputDecoration(
                    prefixIcon: Icon(
                      Icons.folder,
                      color: Color(0xFF999999),
                    ),
                    labelText: '项目目录',
                    labelStyle: TextStyle(color: Color(0xFF999999))),
              ),
            )),
        Container(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: TextField(
                controller: _targetController,
                style: TextStyle(color: Color(0xFF999999)),
                decoration: InputDecoration(
                    prefixIcon: Icon(
                      Icons.assignment_turned_in,
                      color: Color(0xFF999999),
                    ),
                    labelText: '入口文件',
                    labelStyle: TextStyle(color: Color(0xFF999999))),
              ),
            )),
        Container(
          padding: EdgeInsets.only(top: 20),
          alignment: Alignment.center,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Padding(
                  padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                  child: Container(
                    width: 150,
                    child: FlatButton(
                      color: btnColor,
                      highlightColor: btnHighlightColor,
                      colorBrightness: Brightness.dark,
                      splashColor: Colors.grey,
                      hoverColor: btnHoverColor,
                      child: Text("Attach"),
                      onPressed: () {
                        _btnPress(DebugBtnType.attach);
                      },
                    ),
                  )),
              Padding(
                  padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                  child: Container(
                    width: 150,
                    child: FlatButton(
                      padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                      color: btnColor,
                      hoverColor: btnHoverColor,
                      highlightColor: btnHighlightColor,
                      colorBrightness: Brightness.dark,
                      splashColor: Colors.grey,
                      child: Text("Refresh"),
                      onPressed: () {
                        _btnPress(DebugBtnType.refresh);
                      },
                    ),
                  )),
              Padding(
                  padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                  child: Container(
                    width: 150,
                    child: FlatButton(
                      padding: EdgeInsets.fromLTRB(20, 0, 20, 0),
                      color: btnColor,
                      hoverColor: btnHoverColor,
                      highlightColor: btnHighlightColor,
                      colorBrightness: Brightness.dark,
                      splashColor: Colors.grey,
                      child: Text("Reload"),
                      onPressed: () {
                        _btnPress(DebugBtnType.reload);
                      },
                    ),
                  )),
            ],
          ),
        ),
        Expanded(
          child: Container(),
        ),
        debugFooter()
      ],
    ));
  }
}
